Crate boundless_assessor

Crate boundless_assessor 

Assessor is a guest that verifies the fulfillment of a request.

Structs

AssessorInput
Input of the Assessor guest.
Fulfillment
Fulfillment contains a signed request, including offer and requirements, that the prover has completed, and the journal committed into the Merkle tree of the aggregated set of proofs.

Enums

Error
Errors that may occur in the assessor.

Functions

process_tree
Processes a vector of leaves to compute the Merkle root.